Module trace

Module trace 

Trace event types for sequence diagram viewer Trace event types for the sequence diagram viewer.

Events are serialized as newline-delimited JSON (.jsons files). The viewer loads these files to render interactive sequence diagrams.

Structs

NotificationEvent
A JSON-RPC notification (no response expected).
RequestEvent
A JSON-RPC request from one component to another.
ResponseEvent
A JSON-RPC response to a prior request.
TraceWriter
Writer for trace events.

Enums

Protocol
Protocol type for messages.
TraceEvent
A trace event representing message flow between components.

Traits

WriteEvent
Trait for destinations that can receive trace events.