ConductorSuccessor

Trait ConductorSuccessor 

pub trait ConductorSuccessor<Host: ConductorHostRole>:
    Send
    + Sync
    + 'static {
    // Required method
    fn send_message<'a>(
        &self,
        message: Dispatch,
        connection_to_conductor: ConnectionTo<Host::Counterpart>,
        responder: &'a mut ConductorResponder<Host>,
    ) -> BoxFuture<'a, Result<(), Error>>;
}

Required Methods

fn send_message<'a>( &self, message: Dispatch, connection_to_conductor: ConnectionTo<Host::Counterpart>, responder: &'a mut ConductorResponder<Host>, ) -> BoxFuture<'a, Result<(), Error>>

Send a message to the successor.

Implementations on Foreign Types

Source

impl ConductorSuccessor<Agent> for ConnectionTo<Agent>

When the conductor is acting as an agent, messages sent by the last proxy to its successor go to the internal agent (self).

Source

fn send_message<'a>( &self, message: Dispatch, connection: ConnectionTo<Client>, responder: &'a mut ConductorResponder<Agent>, ) -> BoxFuture<'a, Result<(), Error>>

Source

impl<Host: ConductorHostRole> ConductorSuccessor<Host> for Error

Source

fn send_message<'a>( &self, message: Dispatch, connection_to_conductor: ConnectionTo<Host::Counterpart>, responder: &'a mut ConductorResponder<Host>, ) -> BoxFuture<'a, Result<(), Error>>

Implementors