ConductorMessage

Enum ConductorMessage 

pub enum ConductorMessage {
    LeftToRight {
        target_component_index: usize,
        message: Dispatch,
    },
    RightToLeft {
        source_component_index: SourceComponentIndex,
        message: Dispatch,
    },
    McpConnectionReceived {
        acp_url: String,
        actor: McpBridgeConnectionActor,
        connection: McpBridgeConnection,
    },
    McpConnectionEstablished {
        response: McpConnectResponse,
        actor: McpBridgeConnectionActor,
        connection: McpBridgeConnection,
    },
    McpClientToMcpServer {
        connection_id: String,
        message: Dispatch,
    },
    McpConnectionDisconnected {
        notification: McpDisconnectNotification,
    },
}
Messages sent to the conductor’s main event loop for routing.

These messages enable the conductor to route communication between:

  • The editor and the first component
  • Components and their successors in the chain
  • Components and their clients (editor or predecessor)

All spawned tasks send messages via this enum through a shared channel, allowing centralized routing logic in the serve() loop.

Variants



LeftToRight

If this message is a request or notification, then it is going “left-to-right” (e.g., a component making a request of its successor).

If this message is a response, then it is going right-to-left (i.e., the successor answering a request made by its predecessor).

Fields

target_component_index: usize
message: Dispatch


RightToLeft

If this message is a request or notification, then it is going “right-to-left” (e.g., a component making a request of its predecessor).

If this message is a response, then it is going “left-to-right” (i.e., the predecessor answering a request made by its successor).

Fields

source_component_index: SourceComponentIndex
message: Dispatch


McpConnectionReceived

A pending MCP bridge connection request request. The request must be sent back over ACP to receive the connection-id. Once the connection-id is received, the actor must be spawned.

Fields

acp_url: String

The acp:$UUID URL identifying this bridge

actor: McpBridgeConnectionActor

The actor that should be spawned once the connection-id is available.

connection: McpBridgeConnection

The connection to the bridge



McpConnectionEstablished

A pending MCP bridge connection request request. The request must be sent back over ACP to receive the connection-id. Once the connection-id is received, the actor must be spawned.

Fields

actor: McpBridgeConnectionActor

The actor that should be spawned once the connection-id is available.

connection: McpBridgeConnection

The connection to the bridge



McpClientToMcpServer

MCP message (request or notification) received from a bridge that needs to be routed to the final proxy.

Sent when the bridge receives an MCP tool call from the agent and forwards it to the conductor via TCP. The conductor routes this to the appropriate proxy component.

Fields

connection_id: String
message: Dispatch


McpConnectionDisconnected

Message sent when MCP client disconnects

Fields