pub trait ConductorSuccessor<Host: ConductorHostRole>:
Send
+ Sync
+ 'static {
// Required method
fn send_message<'a>(
&self,
message: Dispatch,
connection_to_conductor: ConnectionTo<Host::Counterpart>,
responder: &'a mut ConductorResponder<Host>,
) -> BoxFuture<'a, Result<(), Error>>;
}Required Methods
Sourcefn send_message<'a>(
&self,
message: Dispatch,
connection_to_conductor: ConnectionTo<Host::Counterpart>,
responder: &'a mut ConductorResponder<Host>,
) -> BoxFuture<'a, Result<(), Error>>
fn send_message<'a>( &self, message: Dispatch, connection_to_conductor: ConnectionTo<Host::Counterpart>, responder: &'a mut ConductorResponder<Host>, ) -> BoxFuture<'a, Result<(), Error>>
Send a message to the successor.
Implementations on Foreign Types
Sourceimpl ConductorSuccessor<Agent> for ConnectionTo<Agent>
When the conductor is acting as an agent, messages sent by
the last proxy to its successor go to the internal agent
(self).
impl ConductorSuccessor<Agent> for ConnectionTo<Agent>
When the conductor is acting as an agent, messages sent by
the last proxy to its successor go to the internal agent
(self).